# Class: postgresql::server
#
#
class postgresql::server {
    # include common::utils
    package {"pg-server":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => ["postgresql-9.1", "postgresql-plpython-9.1"],
            default => ["postgresql-server", "postgresql-plpython"],
        },
        ensure => installed,
    }

    $debcreatesql = "ALTER USER postgres WITH PASSWORD '${pgsql_password}';"
    $debchecksql = "SELECT usename FROM pg_shadow WHERE usename='postgres' AND passwd !='';"
	exec { "initdb":
	    command => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "echo \"${debcreatesql}\" > /tmp/ps && 
                        /bin/su postgres -c 'export PGPASSWORD=${pgsql_password}; psql -f /tmp/ps'; rm -f /tmp/ps",
            default => "/bin/chown postgres.postgres /var/lib/pgsql && echo \"${pgsql_password}\" > /tmp/ps &&
                        /bin/su postgres -c \"/usr/bin/initdb /var/lib/pgsql/data --auth='password' --pwfile=/tmp/ps -E UTF8\";
                        rm -rf /tmp/ps",
        },
		require => Package["pg-server"],
		unless => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "echo \"${debchecksql}\" > /tmp/ch &&
                                    su - postgres -c 'export PGPASSWORD=${pgsql_password}; psql -f /tmp/ch'|grep '1 row' && rm -f /tmp/ch",
            default => "/usr/bin/test -e /var/lib/pgsql/data/PG_VERSION",
        }
	}

    service{ "postgresql":
        ensure => running,
        enable => true,
        hasrestart  => true,
        hasstatus   => true,
        require => Exec["initdb"],
    }

	file { "pg_hba.conf":
	    path => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "/etc/postgresql/9.1/main/pg_hba.conf",
            default => "/var/lib/pgsql/data/pg_hba.conf",
        },
		content => template("postgresql/pg_hba.conf.erb"),
		owner => "postgres",
	    group => "postgres",
	    mode => "0600",
	    notify => Service["postgresql"],
		require => Exec["initdb"],
	}

    $postgresql_config = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "/etc/postgresql/9.1/main/postgresql.conf",
        default => "/var/lib/pgsql/data/postgresql.conf",
    }

    exec { "utc-timezone":
        command => "sed -e \"s/^#timezone = \\(.*\\)$/timezone = 'UTC'/\" -i $postgresql_config",
        unless => "grep -E \"^timezone = 'UTC'\" $postgresql_config",
        require => Exec["initdb"],
        notify => Service["postgresql"],
    }
}